
clear all
// 1 - Rename variables, merge unemployment data, etc... This section is mostly coppied from "Analysis/NFCS_AnalysisofFinEd"
{

use "data/NFCS_Data_withFWB_AllAges.dta", clear
	drop fin_ed FinEd NoFinEd
	do "script/NFCS_FinEdPolicies.do"
	
	*Fix D.C. statefips 
	replace statefip = 11 if STATEQ == 9 | stateq == 9

	*Merge in Unemployment Data 
		preserve 
			use "data/youth_unemployment.dta", clear
				rename state statefip
				label data "created in /.../script/nfcs/NFCS_Anylsis.do"
			save "data/youth_empEdit.dta", replace
		restore 
		
		merge m:1 statefip year_18 using "data/youth_empEdit.dta"
			// 1,856 OBS do not merge because we dont have unemployment data for them...
				*1,651 obs were from years in which we do not have amy unemployment data
					*i.e. year_18 < 1999 & year_18 == 2018
				*The remaining (205obs) are from years in which we have data for some states
					*...but that individual state is missing from the data that year (don't know why).
					
	
		
		*Create Ineraction var
		gen fin_ed_BY_unemp = fin_ed * unemp
		label variable fin_ed_BY_unemp "fin_ed interacted with unemployment"
		label variable unemp "Unemployment (16 to 19yrs old) (1-100%)"
	


	tab educ, gen(educ)
	gen HS_only=1 if educ2==1|educ3==1
	gen SoColl=1 if educ4==1|educ5==1
	gen Coll=1 if educ6==1|educ7==1
	tab gender, gen(female)
	rename female2 female
	drop female1 
	replace FinEd=. if FinEd>=2018
	
	gen group=.
	replace group=1 if HS_only==1 & female==0
	replace group=2 if HS_only==1 & female==1
	replace group=3 if Coll==1 & female==0
	replace group=4 if Coll==1 & female==1


	*drop if state=="WI"
	*& state=="LA"
	gen EarlyStates=1 if state=="NH"|state=="NY"|state=="IL"|state=="MI"
	gen Pre1996=1 if state=="NH"|state=="IL"
	
	xtset stateq
	rename Pseud pfwb	

}

// 2 - Create Event Study Variables. 
{
	*pre-treatment vars.
	forvalues i==0(1)5{
		gen FE_pre`i'=0
		replace FE_pre`i'=1 if year_18+`i'==FinEd
		label variable FE_pre`i' "-`i'"
	} 	
	
	*All obs that were 18 more than 5 years before FinEd reqirement
	replace FE_pre5=1 if (FinEd - 5 > year_18) & (FinEd != .)
		label variable FE_pre5 "-5 or more"
		
		*rename variable for t == 0 
		rename FE_pre0 FE
		label variable FE "0"
	
	*post treatment vars.
	forvalues i==1(1)5{
		gen FE_post`i'=0
		replace FE_post`i'=1 if year_18-`i'==FinEd
		label variable FE_post`i' "`i'"
	} 
	
	*All obs that were 18 more than 5 years after FinEd requirement.
	replace FE_post5=1 if (FinEd + 5 < year_18) & (FinEd != .)
		label variable FE_post5 "5 or more"
		
	replace FE_post5=0 if state=="LA" & year_18>=2018

}

// 3- Create additional FWB and PFWB variables (also coppied from "Analysis/NFCS_AnalysisofFinEd"
{
gen qfwb1_3=.
gen qfwb1_5=.
gen qfwb1_8=.
gen qfwb1_13=.
gen qfwb1_17=.
gen qfwb1_19=.
gen qfwb2_1=. 
gen qfwb2_2=.
gen qfwb2_4=.
gen qfwb2_5=.

replace qfwb2_2=0 if J42_2==5
replace qfwb2_2=1 if J42_2==4
replace qfwb2_2=2 if J42_2==3
replace qfwb2_2=3 if J42_2==2
replace qfwb2_2=4 if J42_2==1
replace qfwb2_2=. if J42_2==98|J42_2==99

replace qfwb2_5=J42_1-1
replace qfwb2_5=. if J42_1==98|J42_1==99

replace qfwb1_17=0 if J41_1==5
replace qfwb1_17=1 if J41_1==4
replace qfwb1_17=2 if J41_1==3
replace qfwb1_17=3 if J41_1==2
replace qfwb1_17=4 if J41_1==1
replace qfwb1_17=. if J41_1==98|J41_1==99

replace qfwb1_5=0 if J41_2==5
replace qfwb1_5=1 if J41_2==4
replace qfwb1_5=2 if J41_2==3
replace qfwb1_5=3 if J41_2==2
replace qfwb1_5=4 if J41_2==1

replace qfwb1_13=0 if J41_3==5
replace qfwb1_13=1 if J41_3==4
replace qfwb1_13=2 if J41_3==3
replace qfwb1_13=3 if J41_3==2
replace qfwb1_13=4 if J41_3==1

*Note the multiple quotations put the FWB and Q1, on seperate lines when graphed. 
label variable qfwb2_2 `""FWB" "Q1""'
label variable qfwb2_5 `""FWB" "Q2""'
label variable qfwb1_5 `""FWB" "Q3""'
label variable qfwb1_17 `""FWB" "Q4""'
label variable qfwb1_13 `""FWB" "Q5""'


label variable pfwb2_2 `""PFWB" "Q1""'
label variable pfwb2_5 `""PFWB" "Q2""'
label variable pfwb1_5 `""PFWB" "Q3""'
label variable pfwb1_17 `""PFWB" "Q4""'
label variable pfwb1_13 `""PFWB" "Q5""'

label variable fwb "FWB"
label var pfwb "PFWB"



}

