
clear all

use "data/uas_wPFWB.dta", clear
	label variable pfwb "UAS FWB Score"
	drop _merge
	
	*Only use observations for which they were a primary respondent? 
		*??? !!! do we need to do this !!! ???*


// 1 - Create Relevant Variables for Regressions.
{

	// create state variable 
		global state_var "statereside" //create a global for when we run regressions...
		local state_var "statereside"
		
		statastates, fips(`state_var')
			drop if _merge == 1 // these obs do not have any state indentifer (i.e. lives outside country)
				drop _merge
		rename state_abbrev state // do this to match with "script/UAS_FinEdPolicies.do"


	// - create year variable 
		gen year = start_year 


	// - create birthyear variable 
		gen birthyear = dateofbirth_year


	// - create year_18 variable
			forvalues year = 16/19 {
				gen year_`year' = birthyear + `year'
					label variable year_`year' "year in which person was `year'"
			}


	// - create fin_ed variable
		do "script/UAS_FinEdPolicies.do"


	// - create gender and race dummies 
		gen female = (gender == 0)

	// - create indicator for age 
		drop white black // not sure if the variables previously are correct... drop these...
		gen white = (race == 1)
		gen black = (race == 2)
		*gen hispanic = // !! No indicator for hispanic !! //
	


	// - create indicator for high school graduate (but no more)
		gen hs_grad = (education == 9)
			*skeep if hs_grad == 1

	// - create indicator for if the person is between 18 - 34
		*Note this keep only those who are between 18-34...
		*gen age_18_34 = (inrange(age, 18, 34) == 1)
			*keep if age_18_34 == 1
			
/* We do not use unemployment so no merge...
	// - merge in Youth Unemployment Data. 
		*Note this will keep only observations for which we have unemp data. (drops 21 obs)
			preserve 
				use "data/youth_unemployment.dta", clear
					rename state statereside
					label data "created in /.../UAS_PreReg.do"
				save "data/youth_empEdit.dta", replace
			restore 
			
			merge m:1 statereside year_18 using "data/youth_empEdit.dta"
				keep if _merge == 3
				
		*Create Ineraction var 
			gen fin_ed_BY_unemp = fin_ed * unemp
			label variable fin_ed_BY_unemp "fin_ed interacted with unemployment"
			label variable unemp "Unemployment (16 to 19yrs old) (1-100%)"

*/
} // end section 1

// 2 - Set Fixed Effects
{
	*Note: see section1 for local state_var creation
	xtset `state_var'
}


// 3 - Create Event Study Variables. 
{
	*pre-treatment vars.
	forvalues i==0(1)5{
		gen FE_pre`i'=0
		replace FE_pre`i'=1 if year_18+`i'==FinEd
		label variable FE_pre`i' "-`i'"
	} 	
	
	*All obs that were 18 more than 5 years before FinEd reqirement
	replace FE_pre5=1 if (FinEd - 5 > year_18) & (FinEd != .)
		label variable FE_pre5 "-5 or more"
		
		*rename variable for t == 0 
		rename FE_pre0 FE
		label variable FE "0"
	
	*post treatment vars.
	forvalues i==1(1)5{
		gen FE_post`i'=0
		replace FE_post`i'=1 if year_18-`i'==FinEd
		label variable FE_post`i' "`i'"
	} 
	
	*All obs that were 18 more than 5 years after FinEd requirement.
	replace FE_post5=1 if (FinEd + 5 < year_18) & (FinEd != .)
		label variable FE_post5 "5 or more"
		
	replace FE_post5=0 if state=="LA" & year_18>=2018

}



// 4 - Create correct fips for statereside_hs
	gen statereside_AB = ""
	local obs = _N
	forvalues i = 1/`obs' {
		qui {
			local val = statereside_hs[`i']
			di "`val'"
			local str: label (statereside_hs) `val'
			di "`str'"
			local abbrev = word("`str'", -1)
			local abbrev = subinstr("`abbrev'", "(", "", .)
			local abbrev = subinstr("`abbrev'", ")", "", .)
			replace statereside_AB = "`abbrev'" in `i'
		}
	}
	
	foreach thing in . .a .e country school {
		replace statereside_AB = "" if statereside_AB == "`thing'"
	}
	
	statastates, abbrev(statereside_AB)
		drop if _merge == 2
		
	order statereside* state_fips, first
	rename state_fips statereside_FIPS
	
	
	
// 5 - Merge in 5 Question FWB score, created in script /UAS_genFWB 5 Question.do
	merge 1:1 uasid using "data/uas_FWB_5Q.dta", gen(Q5_mrg)
		//9 people must have been dropped above and were not dropped when making the score. 
		drop if Q5_mrg == 2 
