

// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
	keep if inrange(age, 22, 45) == 1
	
	*clear any old estimates
	eststo clear
	gen all = 1
	
	*make

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args trend scale gender unemp interaction SAMPLE
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

		*Specs for arguments 
		{
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "notrend"
			}
			else if ("`trend'" == "trend") {
				local trend "i.stateq#c.birthyear"
				local file_end "WithTrends"
				local matName = "trend"
			}
			
			*Specs for scale var
			if ("`scale'" == "fwb") {
				local component_vars "qfwb2_2 qfwb2_5 qfwb1_5 qfwb1_17 qfwb1_13"
			}
			else if ("`scale'" == "pfwb") {
				local component_vars "pfwb2_2 pfwb2_5 pfwb1_5 pfwb1_17 pfwb1_13"
			}
			
			*specs for gender
			if "`gender'" == "male" {
				local if "if female == 0 & inrange(age, 18, 45) == 1"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if female == 1 & inrange(age, 18, 45) == 1"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if inrange(age, 18, 45) == 1"
				local gen_counter = 3
			}
			
			*specs for sample 
			
			if "`SAMPLE'" == "OV" {
				local samp_if "& all == 1" 
			}
			else if "`SAMPLE'" == "HS" {
				local samp_if "& HS_only == 1"
			}
			else if "`SAMPLE'" == "SC" {
				local samp_if " & (educ == 4 | educ == 5) "
			}
			else if "`SAMPLE'" == "C" {
				local samp_if " & (educ == 6 | educ == 7)  "
			}
			else if "`SAMPLE'" == "w" {
				local samp_if " & white == 1"
			}
			else if "`SAMPLE'" == "b" {
				local samp_if " & black == 1"
			}
			else if "`SAMPLE'" == "h" {
				local samp_if " & hisp == 1"
			}
	
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"
		local overall_var "`scale'"
		

	
	*Run regression for each variable. 
	foreach dep_var of varlist `overall_var' `component_vars' {
		
		*get mean of dependent variable to report in graph.
		qui: summarize `dep_var' `if' `samp_if'
			local `dep_var'_mean: di %5.2f = `r(mean)'
		
		*run regressions
			qui{
				xtreg `dep_var' `x' `trend' `unemp_var' `interaction_var' `if' `samp_if', fe robust
				eststo `dep_var'_`gender'_`matName'_`SAMPLE'
				estadd local birthyear_fe "X", replace
				estadd local blank " ", replace
				estadd local est_mean "``dep_var'_mean'", replace 
				estadd local gender_dem_fe "X", replace
				if "`scale'" == "pfwb" {
					estadd local year_fe "X", replace
				}
				else if "`scale'" == "fwb" {
					estadd local year_fe " ", replace
				}
			}
				
	} //end foreach dep_var loop.
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "yes" or "no" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...


foreach SAMPLE in HS SC C {		
foreach gender in overall {
	foreach scale in fwb pfwb {
		foreach trend in notrend {
			foreach unemp in NOunemp {
				foreach interaction in no {
					basic_regs `trend' `scale' `gender' `unemp' `interaction' `SAMPLE'
				}
			}
		}
	}
}
}


label var fin_ed "Fin Ed"

	
	
*FWB Results Export -- First Row (Educ)
	# delimit ;
		esttab 
			fwb_overall_notrend_HS fwb_overall_notrend_SC fwb_overall_notrend_C
			pfwb_overall_notrend_HS pfwb_overall_notrend_SC pfwb_overall_notrend_C
			using "out/table4_age22.tex",
					replace
					label
					nonotes
					mtitles(
								"\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}"
								"\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}"
							)
					mgroups("FWB" "PFWB", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(%8.3f)                   
					se(%8.3f)
					keep(fin_ed)
					booktabs
					stats(N r2 est_mean blank birthyear_fe year_fe gender_dem_fe, label("N" "\$R^2$" "DV Mean" " " "Birthyear FE" "Survey Year FE" "Controls") fmt(%6.0fc %5.3f))

					
			
		;
	# delimit cr 



