
clear
// Get if answers were "don't know" or if answers were "prefer not to say"
{

	use "data/FinKnowl_allyears", clear

	rename M6 quiz_interest
	rename M7 quiz_inflation
	rename M8 quiz_bonds
	rename M9 quiz_mortgage
	rename M10 quiz_invest

	foreach quest in interest inflation bonds mortgage invest {

		gen quiz_`quest'_dont_know = (quiz_`quest' == 98)
		label var quiz_`quest'_dont_know "== 1 if responded dont know to quiz_`quest'"
		gen quiz_`quest'_prefer_not = (quiz_`quest' == 99)
		label var quiz_`quest'_prefer_not "== 1 if respnded prefer not to say to quiz_`quest'"
		
		}
		
		keep NFCSID quiz_interest_dont_know - quiz_invest_prefer_not year
		label data "created in AllEduc18-45/Financial Knowledge.do" 
		save "data/FinKnowl_allyears_cleaned", replace
}



// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
	keep if inrange(age, 18, 45) == 1
	
	*Merge in financial knowledge dont know 
		*Need to recode missing NFCSID obs
			gen mis_ind = (NFCSID == .)
			replace NFCSID = _n if NFCSID == . 
		merge 1:1 NFCSID using "data/FinKnowl_allyears_cleaned.dta", gen(finkno_duno)
			drop if finkno_duno == 2 			
			replace NFCSID = . if mis_ind == 1
			drop mis_ind

		

	*clear any old estimates
	eststo clear
	
	// Create randomized correct or incorrect response for all questions where people answered "i duno"
	local add_list ""
	local add_list2 "" // also need to update the quiz_score to only include 5 vars
	foreach var in interest inflation bonds mortgage invest {
	*set seeds for randomization reproducability of (uniform()), NOTE the seed must be set within the loop, not outside. 
	set seed 333
	set sortseed 333
		gen `var'_missing = (quiz_`var' == . & quiz_`var'_dont_know == 1) //make a variable to know if it is missing or not. 
		gen `var'_RA = quiz_`var'_score // make duplicate of the quiz_`var'_score variables.
		replace `var'_RA = (uniform() < .5) if `var'_missing == 1
		if "`var'" == "interest" {
			local add_list "`var'_RA"
			local add_list2 "quiz_`var'_score"
		}
		else {
			local add_list "`add_list' + `var'_RA"
			local add_list2 "`add_list2' + quiz_`var'_score"
		}
	}

	*Make a new quiz score variable but with the random assignments 
		gen quiz_score_RA = `add_list'	
		replace quiz_score = `add_list2'
	

// 1 -  Run regression for factors that predict PFWB / FWB
capture program drop fin_knowledge 
program define fin_knowledge
	args education gender
	// education: {ALL, LTEQ_SumCol, SumCol_Only, ColPlus} - defines what sample of people we use. 
	// gender: overall, male, female.
	
			
		*set education level based on education.
			if "`education'" == "ALL" {
				local educ_if "" 
			}
			else if "`education'" == "LTEQ_SumCol" {
				local educ_if "& (educ <= 4)"
			}
			else if "`education'" == "SumCol_Only" {
				local educ_if "& (educ == 4)"
			}
			else if "`education'" == "ColPlus" {
				local educ_if "& (educ >= 5)"
			}	
			
		*specs for gender
			if "`gender'" == "male" {
				local if "if (female == 0)" 
			}
			else if "`gender'" == "female" {
				local if "if (female == 1)"
			}
			else if "`gender'" == "overall" {
				local if "if (female == 0 | female == 1)"
			}
			
	
	*Prediction Regression	
	foreach dep_var of varlist quiz_score quiz_score_RA {

		# delimit ;
			xtreg 
				`dep_var'
					fin_ed
					i.birthyear i.year female white black hispanic
					`if'
					`educ_if'
					,
					fe robust
					
		;
		# delimit cr 
		
		eststo `dep_var'_`education'_`gender'
		
		*Add indicators for variable things. 
			*get mean of dependent variable to report in graph.
			qui: summarize `dep_var' `if' `educ_if'
			local `dep_var'_mean: di %5.2f = `r(mean)'

			estadd local est_mean "``dep_var'_mean'", replace 
			estadd local state_fe "X", replace
			estadd local blank " ", replace		
			estadd local year_fe "X", replace
	}

end program

*Run program to see what predicts FWB
	foreach gender in overall male female {
		fin_knowledge ALL `gender'
		fin_knowledge ALL `gender'	
	}
	
	
// 2 - Export results into TEX table format
{
	*Label fin_ed variable for table export
	label var fin_ed "Fin Ed"
	
	*Results Export
	# delimit ;
		esttab 
			quiz_score_ALL_overall quiz_score_ALL_male quiz_score_ALL_female
			quiz_score_RA_ALL_overall quiz_score_RA_ALL_male quiz_score_RA_ALL_female
			using "out/table5_A.tex",
					replace
					label
					mtitles("Overall" "Male" "Female" "Overall" "Male" "Female")
					mgroups("\small{No Response = 0}" "\small{No Response = Random Guess}", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(%8.3f)                   
					se(%8.3f)
					keep(fin_ed)
					booktabs
					nonotes
					nolines
					stats(N r2 est_mean, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
					
			
		;
	# delimit cr 


}
