clear all
{

	use "data/FinKnowl_allyears", clear

	rename M6 quiz_interest
	rename M7 quiz_inflation
	rename M8 quiz_bonds
	rename M9 quiz_mortgage
	rename M10 quiz_invest

	foreach quest in interest inflation bonds mortgage invest {

		gen quiz_`quest'_dont_know = (quiz_`quest' == 98)
		label var quiz_`quest'_dont_know "== 1 if responded dont know to quiz_`quest'"
		gen quiz_`quest'_prefer_not = (quiz_`quest' == 99)
		label var quiz_`quest'_prefer_not "== 1 if respnded prefer not to say to quiz_`quest'"
		
		}
		
		rename NFCSID id
		keep id quiz_interest_dont_know - quiz_invest_prefer_not year
		label data "created in AllEduc18-45/Financial Knowledge.do" 
		save "data/FinKnowl_allyears_cleaned", replace
}



// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
	keep if inrange(age, 18, 45) == 1
	gen all = 1
	
	*Make a new NFCSID variable 
		gen double id = NFCSID if NFCSID != .
		replace id = nfcsid if nfcsid != . 

	*Merge in financial knowledge dont know 
		merge 1:1 id using "data/FinKnowl_allyears_cleaned.dta", gen(finkno_duno)
			drop if finkno_duno == 2 			
			
// 0.2 - Preform Factor Analysis on Fin Lit Questions 
{
* redoing factor analysis for each group of questions separately
* first basic fin lit
# delimit ;
	factor quiz_interest_score
		   quiz_inflation_score
		   quiz_bonds_score
		   quiz_mortgage_score
		   quiz_invest_score
		   quiz_interest_dont_know
		   quiz_inflation_dont_know
		   quiz_bonds_dont_know
		   quiz_mortgage_dont_know
		   quiz_invest_dont_know
			,
			ipf
	;
# delimit cr

qui: scree

# delimit ;
factor quiz_interest_score
		   quiz_inflation_score
		   quiz_bonds_score
		   quiz_mortgage_score
		   quiz_invest_score
		   quiz_interest_dont_know
		   quiz_inflation_dont_know
		   quiz_bonds_dont_know
		   quiz_mortgage_dont_know
		   quiz_invest_dont_know,
		   factors(1)
		   ipf
;
# delimit cr
	
predict temp1

	gen bfinlit = temp1 * (-1)
	rename bfinlit finlit_bf
}


	*clear any old estimates
	eststo clear
	
	// Create randomized correct or incorrect response for all questions where people answered "i duno"
	local add_list ""
	local add_list2 "" // also need to update the quiz_score to only include 5 vars
	foreach var in interest inflation bonds mortgage invest {
	*set seeds for randomization reproducability of (uniform()), NOTE the seed must be set within the loop, not outside. 
	set seed 333
	set sortseed 333
		gen `var'_missing = (quiz_`var' == . & quiz_`var'_dont_know == 1) //make a variable to know if it is missing or not. 
		gen `var'_RA = quiz_`var'_score // make duplicate of the quiz_`var'_score variables.
		replace `var'_RA = (uniform() < .5) if `var'_missing == 1
		if "`var'" == "interest" {
			local add_list "`var'_RA"
			local add_list2 "quiz_`var'_score"
		}
		else {
			local add_list "`add_list' + `var'_RA"
			local add_list2 "`add_list2' + quiz_`var'_score"
		}
	}

	*Make a new quiz score variable but with the random assignments 
		gen quiz_score_RA = `add_list'	
		replace quiz_score = `add_list2'
	

// 1 -  Run regression for factors that predict PFWB / FWB
capture program drop fin_knowledge 
program define fin_knowledge
	args SAMPLE gender	
			
			*specs for sample 
			if "`SAMPLE'" == "O" {
				local samp_if "& all == 1" 
			}
			else if "`SAMPLE'" == "H" {
				local samp_if "& HS_only == 1"
			}
			else if "`SAMPLE'" == "S" {
				local samp_if " & (educ == 4 | educ == 5) "
			}
			else if "`SAMPLE'" == "C" {
				local samp_if " & (educ == 6 | educ == 7)  "
			}
			else if "`SAMPLE'" == "w" {
				local samp_if " & white == 1"
			}
			else if "`SAMPLE'" == "b" {
				local samp_if " & black == 1"
			}
			else if "`SAMPLE'" == "h" {
				local samp_if " & hisp == 1"
			}
			
		*specs for gender
			if "`gender'" == "male" {
				local if "if (female == 0)" 
			}
			else if "`gender'" == "female" {
				local if "if (female == 1)"
			}
			else if "`gender'" == "overall" {
				local if "if (female == 0 | female == 1)"
			}
			
	
	*Prediction Regression	
	foreach dep_var of varlist quiz_score finlit_bf {

		# delimit ;
			xtreg 
				`dep_var'
					fin_ed
					i.birthyear i.year female white black hispanic
					`if'
					`samp_if'
					,
					fe robust
					
		;
		# delimit cr 
		
		eststo `dep_var'_`SAMPLE'_`gender'
		
		*Add indicators for variable things. 
			*get mean of dependent variable to report in graph.
			qui: summarize `dep_var' `if' `samp_if'
			local `dep_var'_mean: di %5.2f = `r(mean)'

			estadd local est_mean "``dep_var'_mean'", replace 
			estadd local state_fe "X", replace
			estadd local blank " ", replace		
			estadd local year_fe "X", replace
	}

end program

*Run program to see what predicts FWB
foreach SAMPLE in H S C {
	foreach gender in overall {
		fin_knowledge `SAMPLE' `gender'
	}
}
	
	
// 2 - Export results into TEX table format
{
	*Label fin_ed variable for table export
	label var fin_ed "Fin Ed"
	
	*Results Export
	# delimit ;
		esttab 
			quiz_score_H_overall quiz_score_S_overall quiz_score_C_overall
			finlit_bf_H_overall finlit_bf_S_overall finlit_bf_C_overall
			using "out/appendix_tableA4_B.tex",
					replace
					label
					mtitles(
								"\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}"
								"\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}"
							)
					mgroups("\small{No Response = 0}" "\small{Factor Analysis (1 Factor)}", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(%8.3f)                   
					se(%8.3f)
					keep(fin_ed)
					booktabs
					nonotes
					nolines
					stats(N r2 est_mean, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
					
			
		;
	# delimit cr 


}
