


// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
		keep if inrange(age, 18, 45) == 1

// 1 -  Event Study Regressions with and without state-specific linear trends. 
capture program drop evnt_study
program evnt_study
	args trend scale gender unemp interaction
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run evt study regs for either of these scales
		//gender == "male" or "female" or "overall"
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

		*Specs for arguments 
		{
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "notrend"
			}
			else if ("`trend'" == "trend") {
				local trend "i.stateq#c.birthyear"
				local file_end "WithTrends"
				local matName = "trend"
			}
			
			*Specs for scale var
			if ("`scale'" == "fwb") {
				local component_vars "qfwb2_2 qfwb2_5 qfwb1_5 qfwb1_17 qfwb1_13"
			}
			else if ("`scale'" == "pfwb") {
				local component_vars "pfwb2_2 pfwb2_5 pfwb1_5 pfwb1_17 pfwb1_13"
			}
			
			*specs for gender
			if "`gender'" == "male" {
				local if "if female == 0"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
				local gr_color "edkblue"
				local title ""
				local legend "legend(off)"
			}
			else if "`gender'" == "female" {
				local if "if female == 1"
				local gen_counter = 2
				local gr_color "sienna"
				local title ""
				local legend "legend(off)"
			}
			else if "`gender'" == "overall" {
				local if ""
				local gen_counter = 3
				local gr_color = "forest_green"
				local title ""
				local legend "legend(off)"
				*local legend `"legend(order(3 "Coefficient Estimate" 1 "95% Confidence Interval"))"'
			}
			
			*specs for unemp 
			if "`unemp'" == "unemp" {
				local unemp_var "unemp"
			} 
			else if "`unemp'" == "NOunemp" {
				local unemp_var ""
			}
			
			*specs for interaction
			if "`interaction'" == "yes" {
				local interaction_var "fin_ed_BY_unemp"
				local intFile = "interaction"
			}
			else if "`interaction'" == "no" {
				local interaction_var ""
				local intFile = "NOinteraction"
			}
		} // end specs for arguments 
		
		
	*Vars for event studies 
		local x "i.birthyear i.year female white black hispanic "
		local event "FE_pre5 FE_pre4 FE_pre3 FE_pre2 FE FE_post1 FE_post2 FE_post3 FE_post4 FE_post5"
		
		local overall_var "`scale'"
	
	*clear previous estimates, if any...
	eststo clear
	
	*Run and save regressions for all dependent variables
	display "running event study regressions"
	foreach dep_var of varlist `overall_var' {
		*run regressions
		qui: xtreg `dep_var' `event' `x' `trend' `unemp_var' `interaction_var' `if', fe robust
		eststo `dep_var'_`gender'
	} //end foreach dep_var loop.
	
	
	*Graph individual event studies (from above regs.)  
	set graphics off
		*loop through vars. 
		foreach dep_var of varlist `overall_var'  {
		preserve
		
			*get estimates.
			est restore `dep_var'_`gender'
			
			*get mean of dependent variable to report in graph.
				qui: summarize `dep_var' `if'
					local `dep_var'_mean: di %5.3f = `r(mean)'
			
			*Get matrix of all relevant event study estimates and SE.
				# delimit ; 
				mat `dep_var' = 
								(
								[-5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5]
								\
								[_b[FE_pre5], _b[FE_pre4], _b[FE_pre3], _b[FE_pre2], 0, _b[FE],
								_b[FE_post1], _b[FE_post2], _b[FE_post3], _b[FE_post4], _b[FE_post5]]
								\
								[_se[FE_pre5], _se[FE_pre4], _se[FE_pre3], _se[FE_pre2], 0, _se[FE],
								_se[FE_post1], _se[FE_post2], _se[FE_post3], _se[FE_post4], _se[FE_post5]]
								)
				;
				# delimit cr
			
			*transpose and label matrix
				mat `dep_var' = `dep_var''
				mat colnames `dep_var' = t b se
		
			
			*put matrix into stata		
				clear
				svmat `dep_var', names(col)
					label define t_lab -5 "-5+" -4 "-4" -3 "-3" -2 "-2" -1 "-1" 0 "0" 1 "1" 2 "2" 3 "3" 4 "4" 5 "5+"
					label values t t_lab
				
			*create confidence intervals (currently at 95% level, set (ci_mult = 1.645) for 90%) 
				local ci_mult = 1.96 
					gen ci_h = (b + (se * `ci_mult'))
					gen ci_l = (b - (se * `ci_mult'))
					
				if "`dep_var'" == "`scale'" {
					local yscale "ylabel(-10(5)10)"
					local yline1 "yline(5, lpattern(dash) lcolor(gs13))"
					local yline2 "yline(-5, lpattern(dash) lcolor(gs13))" 
				}
				else {
					local yscale "ylabel(-1(0.5)1)"
					local yline1 "yline(0.5, lpattern(dash) lcolor(gs13))"
					local yline2 "yline(-0.5, lpattern(dash) lcolor(gs13))" 
				}
					
			
			*Graph event study
				# delimit ;
				twoway 
						(sc ci_l t, msymbol(Oh) mcolor(`gr_color'%60) lpattern(dash) lcolor(`gr_color'%60) connect(direct))
						(sc ci_h t, msymbol(Oh) mcolor(`gr_color'%60) lpattern(dash) lcolor(`gr_color'%60) connect(direct))
						(sc b t, msymbol(O) mcolor(`gr_color') lpattern(solid) lcolor(`gr_color') connect(direct))
						,
						`legend'
						scheme(s1mono)
						
						xline(-1, lpattern(dash))
						`yline1'
						`yline2'
						yline(0, lpattern(dash) lcolor(gs13))
						`yscale'
						xlabel(-5(1)5, valuelabel)
						
						`title'
						`subtitle'
						xtitle("Dependent Variable Mean: ``dep_var'_mean'", margin(medsmall))
				;
				# delimit cr
				
				*save graph 
					gr export "out/figure4_`scale'_`gender'.pdf", as(pdf) replace
				
		restore
		} // end. foreach dep_var loop

	eststo clear	

end program

*Run above program for both trends and no trends
	//program evnt_study 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run evt study regs for either of these scales
		//gender == "male" or "female" or "overall"
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...


foreach gender in male female overall {
	foreach scale in fwb pfwb {
		foreach trend in notrend {
			foreach unemp in NOunemp {
				foreach interaction in no {
					evnt_study `trend' `scale' `gender' `unemp' `interaction'
				}
			}
		}
	}
}


set graphics on 
