

// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
		keep if inrange(age, 18, 45) == 1
		gen all = 1
		
		*Fix Financial Goal Question (J43) 
			rename J43 goal //Note: This question is only asked in 2018
			*Recode to 0/1 variable
				replace goal = 0 if goal == 1 | goal == 2
				replace goal = 1 if goal == 3 | goal == 4
			
		*recode Large Unexpected Drop in Income Variable
			rename fin_incdrop incdrop
			replace incdrop = 0 if incdrop == 2
			
		*Make temp income variables so its easy to determine income
		forvalues i = 1/7 {
			if `i' == 1 {
				local top "15"
			}
			else if `i' == 2 {
				local top "25"
			}
			else if `i' == 3 {
				local top "35"
			}
			else if `i' == 4 {
				local top "50"
			}
			else if `i' == 5 {
				local top "75"
			}
			else if `i' == 6 {
				local top "100"
			}
			else if `i' == 7 {
				local top "150"
			}
			gen inc_`top' = (hh_inc <= `i')
				label var inc_`top' "\$`top'K"
		}
		
			
	*clear any stored estimates before we report them in .html table.
		eststo clear		
			

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args gender SAMPLE
		//Args:
		//gender "male" or "female" or "overall"
		//group "ALL" or "HSonly"
		
		*Specs for arguments 
		{			
			*specs for gender
			if "`gender'" == "male" {
				local if "if (female == 0)"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if (female == 1)"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if (female == 1 | female == 0)"
				local gen_counter = 3
			}
			
			
			*specs for sample 
			if "`SAMPLE'" == "H" {
				local if2 "& (HS_only == 1)"
				local group_code = 1
			}
			else if "`SAMPLE'" == "S" {
				local if2 "& (educ == 4 | educ == 5) "
				local group_code = 2
			}
			else if "`SAMPLE'" == "C" {
				local if2 "& (educ == 6 | educ == 7)  "
				local group_code = 3
			}	
			else if "`SAMPLE'" == "A" {
				local if2 "& (all == 1)"
				local group_code = 4
			}
			

			
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"		
		
	

	
	// Run All Income Brackets regression for each variable. 
	foreach dep_var of varlist goal incdrop fin_risk {
		*run regressions
			qui: xtreg `dep_var' `x' `if' `if2', fe robust
			eststo `dep_var'_`gender'_`SAMPLE'
			
			*Add indicators for variable things. 
			*get mean of dependent variable to report in graph.
			qui: summarize `dep_var' `if' `if2'
			local `dep_var'_mean: di %5.2f = `r(mean)'

			estadd local est_mean "``dep_var'_mean'", replace 
				
	} //end foreach dep_var loop.
	
	// Then Run Fin Ed Effect on Being Below a certian income bracket (bracket loop)	
	foreach bracket in 15 25 35 50 75 100 150 {
		*run regressions
			qui: xtreg inc_`bracket' `x' `if' `if2', fe robust
			eststo b`bracket'_`gender'_`SAMPLE'		
	}

	//Save matrix of estimates to graph later
		*first define a blank matrix to store estimates
			mat `gender'_`SAMPLE' = J(6,1,.)	

			
			*loop estimates from above regressions. 
			local counter = 1 //need these to label variables in final dataset
			global varlabs = "" // need these to label variables in final dataset

			foreach bracket in 15 25 35 50 75 100 150 {	
					
				*get estimates.
				est restore b`bracket'_`gender'_`SAMPLE'
				
				*get the mean of each dependent variable. 
					qui: summarize inc_`bracket' `if' `if2'
						local VarMean = r(mean)
					
				*Get the individual estimate for each dep_var
					# delimit ; 
					mat `gender'_`SAMPLE'_MAT = 
									(
									[`counter']
									\
									[`gen_counter']
									\
									[_b[fin_ed]]
									\
									[_se[fin_ed]]
									\
									[`VarMean']
									\
									[`group_code']
									)
					;
					# delimit cr
			
			
				*then update full matrix () with each dep_vars results.
					mat `gender'_`SAMPLE' = (`gender'_`SAMPLE', `gender'_`SAMPLE'_MAT)
					
				*get variable labels 
					local var_lab: variable label inc_`bracket'
						global varlabs `"${varlabs} `counter' `"`var_lab'"'"'
						
					local counter = `counter' + 1
						
			} 
			
			*transpose matrix and delete first column 
				mat `gender'_`SAMPLE' = `gender'_`SAMPLE'[1..6,2..8]
				mat `gender'_`SAMPLE' = (`gender'_`SAMPLE')'
	
		
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//gender "male" or "female" or "overall"
	foreach gender in male female overall {
			foreach SAMPLE in H S C A {
		basic_regs `gender' `SAMPLE'
		}
	}


	
// 3 - Graph basic regressions (H S C) 

		
	*get all estimates into one matrix
		mat est = (overall_H \ overall_S \ overall_C )
		mat colnames est = varnames gender b se mean group
	
	preserve	
		*set graphics off
		
		*put matrix into stata		
			clear
			svmat est, names(col)
			
		*update placements  
			qui {
				replace varnames = varnames + 0.2 if group == 2
				replace varnames = varnames + 0.4 if group == 3
				replace mean = round(mean, 0.01)
			}
			
			*add variable names into dataset (this local was created in the above forloop)
				label define varlabs ${varlabs}
				label values varnames varlabs
					
				
			*create confidence intervals (currently at 95% level, set (ci_mult = 1.645) for 90%) 
				local ci_mult = 1.96 
					gen ci_h = (b + (se * `ci_mult'))
					gen ci_l = (b - (se * `ci_mult'))
					
				
			local	H_color = "edkblue" // set the color for the estimates/SE
			local 	S_color = "sienna"
			local   C_color = "forest_green"
			
			*Grraph basic regressions
				# delimit ;
					twoway
					
						(scatter b varnames if group == 1, msymbol(diamond hollow) mcolor(`H_color') sort)
						(rcap ci_l ci_h varnames if group == 1, mcolor(`H_color'%60) lcolor(`H_color'%60) sort)
						
						(scatter b varnames if group == 2, msymbol(square) mcolor(`S_color')  sort)
						(rcap ci_l ci_h varnames if group == 2, mcolor(`S_color'%60) lcolor(`S_color'%60) sort)
						
						(scatter b varnames if group == 3, msymbol(circle) mcolor(`C_color')  sort)
						(rcap ci_l ci_h varnames if group == 3, mcolor(`C_color'%60) lcolor(`C_color'%60) sort)
						,
						xlabel(1(1)7, labels valuelabel)
					
						yline(0, lpattern(dash) lcolor(gs9))
						ytitle("", margin(medsmall))
						xtitle("Income Less Than or Equal To", margin(small))
						
						scheme(s1mono)
						legend(order(1 "High School" 3 "Some College" 5 "College+") rows(1))

						ylabel(-0.10(0.05)0.10)					;
				# delimit cr
				
				gr export "out/appendix_figureA3_B.pdf", as(pdf) replace
	restore		
		
		


		
		
		
// 4 - Graph basic regressions (MALE // FEMAE) 

	*get all estimates into one matrix
		mat est = (male_A \ female_A )
		mat colnames est = varnames gender b se mean group
		
		*set graphics off
		
		*put matrix into stata		
			clear
			svmat est, names(col)
			
		*update placements  (move male and overall semetricaly around female estimates)
			qui {
				replace varnames = varnames + 0.2 if gender == 2
				replace mean = round(mean, 0.01)
			}
			
			*add variable names into dataset (this local was created in the above forloop)
				label define varlabs ${varlabs}
				label values varnames varlabs
					
				
			*create confidence intervals (currently at 95% level, set (ci_mult = 1.645) for 90%) 
				local ci_mult = 1.96 
					gen ci_h = (b + (se * `ci_mult'))
					gen ci_l = (b - (se * `ci_mult'))
					
				
			local male_color = "forest_green" // set the color for the estimates/SE
			local female_color = "dkorange"

			*Grraph basic regressions
				# delimit ;
					twoway
					
						(scatter b varnames if gender == 1, msymbol(diamond hollow) mcolor(`male_color') sort)
						(rcap ci_l ci_h varnames if gender == 1, mcolor(`male_color'%60) lcolor(`male_color'%60) sort)
						
						(scatter b varnames if gender == 2, msymbol(square) mcolor(`female_color')  sort)
						(rcap ci_l ci_h varnames if gender == 2, mcolor(`female_color'%60) lcolor(`female_color'%60) sort)
						,
						xlabel(1(1)7, labels valuelabel)
					
						yline(0, lpattern(dash) lcolor(gs9))
						ytitle("", margin(medsmall))
						xtitle("Income Less Than or Equal To", margin(small))
						scheme(s1mono)
						legend(order(1 "Male" 3 "Female") rows(1))
						ylabel(-0.10(0.05)0.10)					;
				# delimit cr
				
				gr export "out/appendix_figureA3_A.pdf", as(pdf) replace
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
		
set graphics on


	*mlabel(mean) mlabsize(tiny) mlabposition(12) mlabgap(tiny)
