

// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
		keep if inrange(age, 18, 45) == 1
		
		*Fix Dependent Variables 
			// Do you have a checking account 
				replace hh_checking = 0 if hh_checking == 2
			// Rainy Dat
				*rainday
				rename fin_rainyday rainday
		
				
			// How much you need for retirement
				rename fin_retireclac fin_retcalc
				replace fin_retcalc = 0 if fin_retcalc == 2 
				
				
				gen all = 1
			
			
		
	*clear any stored estimates before we report them in .html table.
		eststo clear		
			

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args gender SAMPLE

	
		
		*Specs for arguments 
		{			
			*specs for gender
			if "`gender'" == "male" {
				local if "if (female == 0)"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if (female == 1)"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if (female == 1 | female == 0)"
				local gen_counter = 3
			}
			
			*specs for sample 
			if "`SAMPLE'" == "O" {
				local samp_if "& all == 1" 
			}
			else if "`SAMPLE'" == "H" {
				local samp_if "& HS_only == 1"
			}
			else if "`SAMPLE'" == "S" {
				local samp_if " & (educ == 4 | educ == 5) "
			}
			else if "`SAMPLE'" == "C" {
				local samp_if " & (educ == 6 | educ == 7)  "
			}
						
			
			
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"		
		
	

	
	//loop through all dep. variables
	foreach dep_var of varlist hh_checking rainday fin_retcalc {
		
		*run regressions
			qui: xtreg `dep_var' `x' `if' `samp_if', fe robust
			eststo `dep_var'_`gender'_`SAMPLE'
			
			*Add indicators for variable things. 
			*get mean of dependent variable to report in graph.
			qui: summarize `dep_var' `if' `samp_if'
			local `dep_var'_mean: di %5.2f = `r(mean)'

			estadd local est_mean "``dep_var'_mean'", replace 
				
	} //end foreach dep_var loop.
	
	
		
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//gender "male" or "female" or "overall"
	foreach gender in male female overall {
			foreach SAMPLE in O H S C {
		basic_regs `gender' `SAMPLE'
		}
	}

// 2 - Make Tables for Overall Results 
	label var hh_checking "Checking/Savings Acct"
	label var rainday "Rainy Day Acct"
	label var fin_ed "Fin Ed"
	label var fin_retcalc "How much you need for Retirement"

foreach dep_var in hh_checking rainday fin_retcalc  {
		foreach line_type in nolines {
	*Results Export
		# delimit ;
			esttab 
				`dep_var'_overall_O 
				`dep_var'_male_O
				`dep_var'_female_O
				`dep_var'_overall_H
				`dep_var'_overall_S
				`dep_var'_overall_C
				using "out/table6_`dep_var'.tex",
						replace
						label
						mtitles("Overall" "Male" "Female" 
								"\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}")
						mgroups("\small{Overall Effects}" "\small{Split by Education}", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
						ar2
						star(* 0.10 ** 0.05 *** 0.01)
						b(%8.3f)                   
						se(%8.3f)
						keep(fin_ed)
						booktabs
						nonotes
						width(\textwidth)
						`line_type'
						stats(N r2 est_mean, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
			;
		# delimit cr 
		}
	}



