


// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
		keep if inrange(age, 18, 45) == 1

		gen all = 1
// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args trend scale gender unemp interaction SAMPLE
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

		*Specs for arguments 
		{
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "notrend"
			}
			else if ("`trend'" == "trend") {
				local trend "i.stateq#c.birthyear"
				local file_end "WithTrends"
				local matName = "trend"
			}
			
			*Specs for scale var
			if ("`scale'" == "fwb") {
				local component_vars "qfwb2_2 qfwb2_5 qfwb1_5 qfwb1_17 qfwb1_13"
			}
			else if ("`scale'" == "pfwb") {
				local component_vars "pfwb2_2 pfwb2_5 pfwb1_5 pfwb1_17 pfwb1_13"
			}
			
			*specs for gender
			if "`gender'" == "male" {
				local if "if female == 0 & inrange(age, 18, 45) == 1"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if female == 1 & inrange(age, 18, 45) == 1"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if inrange(age, 18, 45) == 1"
				local gen_counter = 3
			}
			
			*specs for unemp 
			if "`unemp'" == "unemp" {
				local unemp_var "u"
			} 
			else if "`unemp'" == "NOu" {
				local unemp_var ""
			}
			
			*specs for interaction
			if "`interaction'" == "yes" {
				local interaction_var "fin_ed_BY_unemp"
				local intFile = "interaction"
			}
			else if "`interaction'" == "no" {
				local interaction_var ""
				local intFile = "NOinteraction"
			}
			
			
					*specs for sample 
			
			if "`SAMPLE'" == "O" {
				local samp_if "& all == 1" 
			}
			else if "`SAMPLE'" == "H" {
				local samp_if "& HS_only == 1"
			}
			else if "`SAMPLE'" == "S" {
				local samp_if " & (educ == 4 | educ == 5) "
			}
			else if "`SAMPLE'" == "C" {
				local samp_if " & (educ == 6 | educ == 7)  "
			}
			else if "`SAMPLE'" == "w" {
				local samp_if " & white == 1"
			}
			else if "`SAMPLE'" == "b" {
				local samp_if " & black == 1"
			}
			else if "`SAMPLE'" == "h" {
				local samp_if " & hisp == 1"
			}
	
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"
		local overall_var "`scale'"
		
		
	
	
	*Run and save regressions for all dependent variables
	display "running basic regressions"
		
	*clear any stored estimates before we report them in .html table.
		eststo clear
	
	*Run regression for each variable. 
	foreach dep_var of varlist `overall_var' `component_vars' {
		*run regressions
			qui: xtreg `dep_var' `x' `trend' `unemp_var' `interaction_var' `if' `samp_if', fe robust
			eststo `dep_var'_`gender'_`SAMPLE'
				
	} //end foreach dep_var loop.
	
	//Save matrix of estimates to graph later
		
		*first define a blank matrix to store estimates
			mat `gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE' = J(5,1,.)	

					
		*loop estimates from above regressions. 
			local counter = 1 //need these to label variables in final dataset
			global varlabs = "" // need these to label variables in final dataset
					
			foreach dep_var of varlist `component_vars' {
					
				*get estimates.
				est restore `dep_var'_`gender'_`SAMPLE'
				
				*get the mean of each dependent variable. 
					qui: summarize `dep_var' `if' `samp_if'
						local VarMean = r(mean)
					
				*Get the individual estimate for each dep_var
					# delimit ; 
					mat `dep_var'_`gender'_`SAMPLE'_MAT = 
									(
									[`counter']
									\
									[`gen_counter']
									\
									[_b[fin_ed]]
									\
									[_se[fin_ed]]
									\
									[`VarMean']
									)
					;
					# delimit cr
			
			
				*then update full matrix () with each dep_vars results.
					mat `gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE' = (`gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE', `dep_var'_`gender'_`SAMPLE'_MAT)
					
				*get variable labels 
					local var_lab: variable label `dep_var'
						global `scale'_varlabs `"${`scale'_varlabs} `counter' `"`var_lab'"'"'
						
					local counter = `counter' + 1
						
				} //end foreach dep_var loop.
			
			*transpose matrix and delete first column 
				mat `gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE' = `gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE'[1..5,2..6]
				mat `gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE' = (`gender'_`scale'_`matName'_`unemp'_`interaction'_`SAMPLE')'

		eststo clear
		
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "yes" or "no" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

foreach SAMPLE in H S C {		
foreach gender in overall {
	foreach scale in fwb pfwb {
		foreach trend in notrend {
			foreach unemp in NOu {
				foreach interaction in no {
					basic_regs `trend' `scale' `gender' `unemp' `interaction' `SAMPLE'
				}
			}
		}
	}
}
}






capture program drop graph_basic_regs_educ
program graph_basic_regs_educ
	args trend scale unemp interaction SAMPLE
		//trend == notrend, run basic regs and graph with no state specific linear trends
		//trend == trend, run basic regs and graph with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components	
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...
		
		if "`interaction'" == "yes" {
			local intFile = "interaction"
		}
		else if "`interaction'" == "no" {
			local intFile = "NOinteraction"
		}
		
	*get all estimates into one matrix
	mat est = (overall_`scale'_notrend_NOu_no_H, J(5, 1, 1)\overall_`scale'_notrend_NOu_no_S, J(5, 1, 2) \ overall_`scale'_notrend_NOu_no_C, J(5, 1, 3))
		mat colnames est = varnames gender b se mean sample
	
		
		set graphics off
		
		*put matrix into stata		
			clear
			svmat est, names(col)
			
		*update placements  (move male and overall semetricaly around female estimates)
			qui {
				replace varnames = varnames + 0.2 if sample == 2
				replace varnames = varnames + 0.4 if sample == 3
				replace mean = round(mean, 0.01)
			}
			
			*add variable names into dataset (this local was created in the above forloop)
				label define `scale'_varlabs ${`scale'_varlabs}
				label values varnames `scale'_varlabs
					
				
			*create confidence intervals (currently at 95% level, set (ci_mult = 1.645) for 90%) 
				local ci_mult = 1.96 
					gen ci_h = (b + (se * `ci_mult'))
					gen ci_l = (b - (se * `ci_mult'))
					
				
			local hs_color = "edkblue" // set the color for the estimates/SE
			local sc_color = "sienna"
			local c_color = "forest_green"
			
			*Grraph basic regressions
				# delimit ;
					twoway
					
						(scatter b varnames if sample == 1, msymbol(square) mcolor(`hs_color')  sort)
						(rcap ci_l ci_h varnames if sample == 1, mcolor(`hs_color'%60) lcolor(`hs_color'%60) sort)
						
						(scatter b varnames if sample == 2, msymbol(square) mcolor(`sc_color')  sort)
						(rcap ci_l ci_h varnames if sample == 2, mcolor(`sc_color'%60) lcolor(`sc_color'%60) sort)
						
						(scatter b varnames if sample == 3, msymbol(circle) mcolor(`c_color') sort)
						(rcap ci_l ci_h varnames if sample == 3, mcolor(`c_color'%60) lcolor(`c_color'%60) sort)
						,
						xlabel(1(1)5, labels valuelabel)
						ylabel(-0.75(0.25)0.75)
						yline(-0.25 0.25 0.5 -0.5, lpattern(dash) lcolor(gs13))
						yline(0, lpattern(dash) lcolor(gs9))
						ytitle("Coefficient Estimate", margin(medsmall))
						xtitle(" ", margin(small))
						scheme(s1mono)
						legend(order(1 "High School Only" 3 "Some College" 5 "College Plus") rows(1))
					;
				# delimit cr
				
				gr export "out/figure7_`scale'.pdf", as(pdf) replace
			
		
		
end program 


*run above program
// note dont have to do a loop for gender because all genders graphed on one.
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//unemp == "yes" or "no" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...


foreach scale in fwb pfwb {
	foreach trend in notrend {
		foreach unemp in NOu {
			foreach interaction in no {
				graph_basic_regs_educ `trend' `scale' `unemp' `interaction' 

			}
		}
	}
}


set graphics on


	*mlabel(mean) mlabsize(tiny) mlabposition(12) mlabgap(tiny)
