
// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
		keep if inrange(age, 18, 45) == 1
		
		gen all = 1
	

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args trend scale SAMPLE unemp interaction dropState
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//SAMPLE == {H S C}
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...
		//dropState == "Enter a state fip (ex: 56 == WY) to drop in the regression"
		*Specs for arguments 
		{
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "notrend"
			}
			else if ("`trend'" == "trend") {
				local trend "i.stateq#c.birthyear"
				local file_end "WithTrends"
				local matName = "trend"
			}
			
			*Specs for scale var
			if ("`scale'" == "fwb") {
				local component_vars "qfwb2_2 qfwb2_5 qfwb1_5 qfwb1_17 qfwb1_13"
			}
			else if ("`scale'" == "pfwb") {
				local component_vars "pfwb2_2 pfwb2_5 pfwb1_5 pfwb1_17 pfwb1_13"
			}
			
			
			*specs for sample 
			if "`SAMPLE'" == "H" {
				local if "if HS_only == 1"
				local gen_counter = 1
			}
			else if "`SAMPLE'" == "S" {
				local if "if (educ == 4 | educ == 5) "
				local gen_counter = 2
			}
			else if "`SAMPLE'" == "C" {
				local if "if (educ == 6 | educ == 7)  "
				local gen_counter = 3
			}		
			
		
			*specs for unemp 
			if "`unemp'" == "unemp" {
				local unemp_var "unemp"
			} 
			else if "`unemp'" == "NOun" {
				local unemp_var ""
			}
			
			*specs for interaction
			if "`interaction'" == "yes" {
				local interaction_var "fin_ed_BY_unemp"
				local intFile = "interaction"
			}
			else if "`interaction'" == "no" {
				local interaction_var ""
				local intFile = "NOinteraction"
			}
			
			*specs for dropState
				local dropState_if "& (statefip != `dropState')"
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"
		local overall_var "`scale'"
		
		
	
	
	*Run and save regressions for all dependent variables
	display "running basic regressions"
		
	*clear any stored estimates before we report them in .html table.
		eststo clear
	
	*Run regression for each variable. 
	foreach dep_var of varlist `overall_var' {
		*run regressions
			qui: xtreg `dep_var' `x' `trend' `unemp_var' `interaction_var' `if' `dropState_if', fe robust
			eststo `dep_var'_`SAMPLE'_`dropState'
				
	} //end foreach dep_var loop.
	
	//Save matrix of estimates to graph later
		
		*first define a blank matrix to store estimates
			mat `SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState' = J(6,1,.)	// the 6 stores the counter, gen counter,dropStateFIP etc...

					
		*loop estimates from above regressions. 
			local counter = 1 //need these to label variables in final dataset
			global varlabs = "" // need these to label variables in final dataset
					
			foreach dep_var of varlist `overall_var' {
					
				*get estimates.
				est restore `dep_var'_`SAMPLE'_`dropState'
				
				*get the mean of each dependent variable. 
					qui: summarize `dep_var' `if' `dropState_if'
						local VarMean = r(mean)
					
				*Get the individual estimate for each dep_var
					# delimit ; 
					mat `dep_var'_`SAMPLE'_`dropState'_MAT = 
									(
									[`counter']
									\
									[`gen_counter']
									\
									[`dropState']
									\
									[_b[fin_ed]]
									\
									[_se[fin_ed]]
									\
									[`VarMean']
									)
					;
					# delimit cr
			
			
				*then update full matrix () with each dep_vars results.
					mat `SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState' = (`SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState', `dep_var'_`SAMPLE'_`dropState'_MAT)
					
	
					local counter = `counter' + 1
						
				} //end foreach dep_var loop.
			
			*transpose matrix and delete first column 
				mat `SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState' = `SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState'[1..6,2]
				mat `SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState' = (`SAMPLE'_`scale'_`matName'_`unemp'_`interaction'_`dropState')'

		eststo clear
		
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "yes" or "no" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...
levelsof statefip, local(statefips)
foreach dropState of local statefips {
	foreach SAMPLE in S C H {
		foreach scale in fwb pfwb {
			foreach trend in notrend {
				foreach unemp in NOun {
					foreach interaction in no {
						basic_regs `trend' `scale' `SAMPLE' `unemp' `interaction' `dropState'
					}
				}
			}
		}
	}
}



*combine all state and gender estimates together into one matrix for each scale. 
levelsof statefip, local(statefips)	
	foreach scale in fwb pfwb {
		mat `scale' = J(1, 6, .)
		foreach dropState of local statefips {
			# delimit ;
			mat `scale' = (`scale' \ 
							C_`scale'_notrend_NOun_no_`dropState'\
							S_`scale'_notrend_NOun_no_`dropState' \
							H_`scale'_notrend_NOun_no_`dropState' )
			;
			# delimit cr
		}
		mat colnames `scale' = varnames gender statefip b se mean
	}



*Graph histogram of each gender and each scale.
foreach scale in fwb pfwb {
	
	*put matrix into stata of estaimtes run above.		
		clear
		svmat `scale', names(col)
		drop if statefip == . // drop blank row at top
		statastates, fips(statefip)
			drop _merge
		
		*Need to increment variable placement (varnames) by state
			qui: levelsof statefip, local(statefips)	
			local counter = 1
			foreach fip of local statefips {
				replace varnames = `counter' if statefip == `fip'
				local counter = `counter' + 1
			}
		
		*Make value labels for statefips
		qui: levelsof varnames, local(statenums)
		local st_val_lab ""
		foreach st of local statenums {
			qui: levelsof state_abbrev if varnames == `st', local(abbrev)
			local st_val_lab `"`st_val_lab' `st' `abbrev' "'
		}

		label define st_val_lab `st_val_lab'
		label values varnames st_val_lab
		
		label define gender_val_lab 1 "HS" 2 "SC" 3 "C"
		label values gender gender_val_lab
		
		*create confidence intervals (currently at 95% level, set (ci_mult = 1.645) for 90%) 
		local ci_mult = 1.96 
			gen ci_h = (b + (se * `ci_mult'))
			gen ci_l = (b - (se * `ci_mult'))
			
		*Set colors for histogram fill		
		local SC_color = "edkblue" // set the color for the estimates/SE
		local C_color = "sienna"
		local HS_color = "forest_green"
		
		*Make scale all uppercase 
			local scale_title_name = upper("`scale'")
		
	*Grraph histogram of regression estimate. 
	forvalues gender_code = 1/3 {
		if `gender_code' == 2 {
			local xtitle " "
			local ytitle "Fraction"
			local xscale ""
			local xtitle_marg "xtitle(, margin(medsmall))"
		}
		else {
			local xtitle " "
			local ytitle "Fraction"
			local xscale ""
			local xtitle_marg ""
		}

			
		*Set locals for graphing
			local gen_title: label gender_val_lab `gender_code'
			*These are estimates from Tables 4 (Overall Effects Table, byEduc) 
			local fwb_HS_est = -1.390
			local fwb_SC_est = 1.021
			local fwb_C_est = 1.577
			local pfwb_HS_est = -0.132  
			local pfwb_SC_est = 0.517
			local pfwb_C_est = 1.321
		
		# delimit ;
			histogram b if gender == `gender_code',
				fraction
				fcolor(``gen_title'_color'%60) lcolor(``gen_title'_color'%80)
				xtitle("`xtitle'")
				ytitle("`ytitle'")
				`xtitle_marg'
				`xscale'
				legend(off)	
				scheme(s1mono)
				xline(``scale'_`gen_title'_est', lwidth(medthick) extend lcolor(black))
				xlabel(-1(0.5)2)
				ylabel(0(0.1)0.4)
			;
		# delimit cr
		
		gr export "out/appendix_figureA5_`scale'_`gen_title'.pdf", as(pdf) replace
	} // end for each gender code
} // end for each scale loop.




	


