

// 0 - Load data and create variables
	do "script/NFCS_PreReg.do"
	
	keep if inrange(age, 18, 45) == 1
	
	*clear any old estimates
	eststo clear

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args trend scale gender unemp interaction
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "unemp" or "NOunemp" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

		*Specs for arguments 
		{
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "notrend"
			}
			else if ("`trend'" == "trend") {
				local trend "i.stateq#c.birthyear"
				local file_end "WithTrends"
				local matName = "trend"
			}
			
			*Specs for scale var
			if ("`scale'" == "fwb") {
				local component_vars "qfwb2_2 qfwb2_5 qfwb1_5 qfwb1_17 qfwb1_13"
			}
			else if ("`scale'" == "pfwb") {
				local component_vars "pfwb2_2 pfwb2_5 pfwb1_5 pfwb1_17 pfwb1_13"
			}
			
			*specs for gender
			if "`gender'" == "male" {
				local if "if female == 0 & inrange(age, 18, 45) == 1"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if female == 1 & inrange(age, 18, 45) == 1"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if inrange(age, 18, 45) == 1"
				local gen_counter = 3
			}
			
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		local x "fin_ed i.birthyear i.year female white black hispanic"
		local overall_var "`scale'"
		

	
	*Run regression for each variable. 
	foreach dep_var of varlist `overall_var'  {
		
		*get mean of dependent variable to report in graph.
		qui: summarize `dep_var' `if'
			local `dep_var'_mean: di %5.2f = `r(mean)'
		
		*run regressions
			
				xtqreg `dep_var' `x' `trend' `unemp_var' `interaction_var' `if', i(stateq) q(.75) 
				eststo `dep_var'_`gender'_`matName'
				estadd local birthyear_fe "X", replace
				estadd local blank " ", replace
				estadd local est_mean "``dep_var'_mean'", replace 
				estadd local gender_dem_fe "X", replace
				if "`scale'" == "pfwb" {
					estadd local year_fe "X", replace
				}
				else if "`scale'" == "fwb" {
					estadd local year_fe " ", replace
				}
			
				
	} //end foreach dep_var loop.
end program 

*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//scale == "fwb or pfwb" -- the program will run basic regs for either of these components
		//gender "male" or "female" or "overall"
		//unemp == "yes" or "no" this will include unemployment as a control variable
		//interaction "yes" or "no" this will include unemployment interacted with fin_ed as a control variable...

foreach gender in male female overall {
	foreach scale in fwb pfwb {
		foreach trend in notrend {
			foreach unemp in NOunemp {
				foreach interaction in no {
					basic_regs `trend' `scale' `gender' `unemp' `interaction'
				}
			}
		}
	}
}



label var fin_ed "Fin Ed"


// 2 - Export results into table format

	*FWB Results Export
	# delimit ;
		esttab 
			fwb_overall_notrend fwb_male_notrend fwb_female_notrend
			pfwb_overall_notrend pfwb_male_notrend pfwb_female_notrend
			using "out/appendix_tableA5_Q75.tex",
					replace
					label
					nonotes
					mtitles("Overall" "Male" "Female" "Overall" "Male" "Female")
					mgroups("FWB" "PFWB", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(%8.3f)                   
					se(%8.3f)
					keep(fin_ed)
					booktabs
					stats(N est_mean blank birthyear_fe year_fe gender_dem_fe, label("N" "DV Mean" " " "Birthyear FE" "Survey Year FE" "Controls") fmt(%6.0fc %5.3f))
					
			
		;
	# delimit cr 

	
