

// 0 - Load data and create variables
	qui: do "script/NFCS_PreReg.do" // this loads the panel, creates variables, etc...
	
	
	*Update Race Variables.
	drop white black hispanic 
	
	gen white = (ethnicity == 1)
	gen black = (ethnicity == 2)
	gen hispanic = (ethnicity == 3)
	gen other = (ethnicity == 4 | ethnicity == 5)
	
	*Keep age group of interest.
		local lo_age = 18
		local hi_age = 45
		
		keep if inrange(age, `lo_age', `hi_age')

		
	*Make additional regression variables 
	{
		*Bin Income into catagories. 
			* !!! - Assuming that hh_inc (household income) is the income variable of choice. 
			*There are 8 catagories, so will bin into 4?
				local lo_group = 1 // these locals will be updated in the loop below.
				local hi_group = 2 			
			foreach inc_group in low med_low med_high high {
				di "binning hh_inc responses coded: {`lo_group' --> `hi_group'} into the `inc_group' income group."
				
				gen `inc_group'_inc = 0 
				replace `inc_group'_inc = 1 if hh_inc == `lo_group' | hh_inc == `hi_group'
				
				local lo_group = `lo_group' + 2
				local hi_group = `hi_group' + 2
			} 
		
		
		*Homeownership var
		*Recode homeownership variable (home_own) from 1/2 to 0/1
			replace home_own = 0 if home_own == 2
		
		
		*Bin all Alternative Financial Service Variables into one.
			gen alt_fin = 0 
			label var alt_fin "==1 if they have used payday, autotitle, rent2own, pawn in last 5 years."
			*Each of these five year variables == 1 if they have never use it
			# delimit ;
				replace alt_fin = 1 
				if
					debt_fiveyr_payday > 1 
					|
					debt_fiveyr_autotitle > 1
					|
					debt_fiveyr_rent2own > 1
					| 
					debt_fiveyr_pawn > 1
			;
			# delimit cr 
		
		
		*Set state fips as panel var
			xtset stateq
		
	}
	

// 1 -  Run regression for factors that predict PFWB / FWB
capture program drop predict_fwb 
program define predict_fwb
	args scale education
	// scale: {pfwb, fwb} - defines which scale used when predicting fwb / pfwb
	// education: {ALL, LTEQ_SumCol, SumCol_Only, ColPlus} - defines what sample of people we use. 

	
		*set year fixed effects or not based on scale
			if "`scale'" == "fwb" {
				local year_fe ""
			}
			else if "`scale'" == "pfwb" {
				local year_fe "i.year"
			}
			
		*set education level based on education.
			if "`education'" == "ALL" {
				local educ_if "" 
			}
			else if "`education'" == "LTEQ_SumCol" {
				local educ_if "if (educ <= 4)"
			}
			else if "`education'" == "SumCol_Only" {
				local educ_if "if (educ == 4)"
			}
			else if "`education'" == "ColPlus" {
				local educ_if "if (educ >= 5)"
			}			
			
	
	*Prediction Regression
	*Notes:
		*currently all income variables are relative to the "high" >= $100,000 income group. 
	# delimit ;
		xtreg
			`scale' 
				low_inc med_low_inc med_high_inc
				female
				black hispanic other
				home_own
				alt_fin
				`year_fe'
				`educ_if'
				,
				fe robust
				
	;
	# delimit cr 
	
	eststo `scale'_`education'
	
	*Add indicators for variable things. 
		*get mean of dependent variable to report in graph.
		qui: summarize `scale' `educ_if'
		local `dep_var'_mean: di %5.2f = `r(mean)'

		estadd local est_mean "``dep_var'_mean'", replace 
		estadd local state_fe "X", replace
		estadd local blank " ", replace		
		if "`scale'" == "pfwb" {
			estadd local year_fe "X", replace
		}
		else if "`scale'" == "fwb" {
			estadd local year_fe " ", replace
		}
				

end program

*Run program to see what predicts FWB
	predict_fwb fwb ALL
	predict_fwb pfwb ALL	
	
// 3 - Export results into PDF of coefficient plotted. 
{
	*Re-Label all variables so the Plot looks good
		label var low_inc `""Household Income"  "less than \$25,000"'
		label var med_low_inc `""Household Income at least \$25,000" "but less than \$50,000""'
		label var med_high_inc `""Household Income at least \$50,000" "but less than \$100,000""'
		label var female "Female"
		label var white "White"
		label var black "African American"
		label var hispanic "Hispanic or Latino"
		label var home_own `""Respondent or Partner" "currently owns home""'
		label var alt_fin `""Use of Alternative Financial" "Services in last 5 years""'
		
		
		*Plot estimates
		coefplot (fwb_ALL, label(FWB) ciopts(lcolor(navy)) mcolor(navy)) ///
				 (pfwb_ALL, label(PFWB) ciopts(lcolor(cranberry)) mcolor(cranberry)) ///
				 ,  drop(_cons 2*) ///
					xline(0) ///
					scheme(s1mono) ///
					ylabel(, labsize(vsmall)) ///
					xlabel(-10(5)5) xtick(-11(1)5) ///
					levels(95)
					   
					   
			gr export "out/figure3.pdf", as(pdf) replace

}
