
// 0 - Load data and create variables
	do "script/UAS_PreReg.do"
	
	keep if inrange(age, 18, 45) == 1
	*rename the 10 question score variable 
	rename pfwb FWB_10Q
		label var FWB_10Q "10 Question FWB Score"
		label var FWB_5Q  "5  Question FWB Score"

	gen all = 1

*Clear estimates
eststo clear

// 1 -  Basic regression (overall effect) with and without state-specific linear trends. (also stores matricies of estimates) 
capture program drop basic_regs
program basic_regs
	args trend gender SAMPLE
		//Args: 
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 
		//gender "male" or "female" or "overall"
		
		*Specs for arguments 
		{
			
			* Specs for trend var
			if ("`trend'" == "notrend") {
				local trend ""
				local file_end "NoTrends"
				local matName = "noT"
			}
			else if ("`trend'" == "trend") {
				local trend "i.${state_var}#c.birthyear"
				local file_end "WithTrends"
				local matName = "trnd"
			}
			
			
			*specs for gender
			if "`gender'" == "male" {
				local if "if (female == 0)"
				local gen_counter = 1 //this is for the matrix of estimates to differentiate
			}
			else if "`gender'" == "female" {
				local if "if (female == 1)"
				local gen_counter = 2
			}
			else if "`gender'" == "overall" {
				local if "if (female == 1 | female == 0)"
				local gen_counter = 3
			}
			
			*specs for sample 
			
			if "`SAMPLE'" == "O" {
				local samp_if "& all == 1" 
			}
			else if "`SAMPLE'" == "H" {
				local samp_if "& education == 9"
			}
			else if "`SAMPLE'" == "S" {
				local samp_if " & inrange(education, 10, 12) "
			}
			else if "`SAMPLE'" == "C" {
				local samp_if " & (education >= 13)  "
			}
			
			
		} // end specs for arguments 
		
		
	*Vars for basic regressions 
		order FWB_5Q, before(FWB_10Q)
		local depvars "FWB_5Q - fwb10_left"
		local x "fin_ed i.birthyear i.year female white black" // note: no indicator for hispanic.
		
		
	
	*Run regression for each variable. 
	foreach dep_var of varlist `depvars' {
	
		*get mean of dependent variable to report in graph.
		qui: summarize `dep_var' `if' `samp_if'
			local `dep_var'_mean: di %4.2f = `r(mean)'
		
		*run regressions
			qui: xtreg `dep_var' `x' `trend' `unemp_var' `interaction_var' `if' `samp_if', fe robust
			qui: eststo `dep_var'_`gender'_`matName'_`SAMPLE'
			qui: estadd local MEANs "``dep_var'_mean'", replace
				
	} //end foreach dep_var loop.
	
end program 


*Run above program for both trends and no trends and also fwb and pfwb and also for multiple genders
	//program basic_regs 
		//Args:
		//trend == notrend, run event study with no state specific linear trends
		//trend == trend, run event study with state specific linear trends 

		//gender "male" or "female" or "overall"
		
foreach SAMPLE in O H S C {		
	foreach gender in overall female male {
		foreach trend in notrend {
			basic_regs `trend' `gender' `SAMPLE'
		}
	}	
}

			label var fwb1_exp "UAS Q1" 
			label var fwb2_getby "UAS Q2"
			label var fwb3_secure "UAS Q3"
			label var fwb4_concern "UAS Q4"
			label var fwb5_never "UAS Q5"
			label var fwb6_enjoy "UAS Q6"
			label var fwb7_behind "UAS Q7"
			label var fwb8_control "UAS Q8"
			label var fwb9_strain "UAS Q9"
			label var fwb10_left "UAS Q10"


	label var fin_ed "Fin Ed"

	
 	// 10 Question Version Results
	# delimit ;
		esttab 
			FWB_10Q_overall_noT_H FWB_10Q_overall_noT_S FWB_10Q_overall_noT_C 
			using "out/appendix_tableB2_B.tex",
					replace
					label
					nonotes
					mgroups("FWB", pattern(1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					mtitles("\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}")					
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(3)                   
					se(3)
					keep(fin_ed)
					booktabs
					stats(N r2 MEANs, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
					
			
		;
	# delimit cr 

	// 5 Question Version Results
	# delimit ;
		esttab 
			FWB_5Q_overall_noT_H FWB_5Q_overall_noT_S FWB_5Q_overall_noT_C 
			using "out/appendix_tableB3_B.tex",
					replace
					label
					nonotes
					mgroups("FWB", pattern(1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))        
					mtitles("\shortstack{High \\ School}"
								"\shortstack{Some \\ College}"
								"\shortstack{College+}")						
					ar2
					star(* 0.10 ** 0.05 *** 0.01)
					b(3)                   
					se(3)
					keep(fin_ed)
					booktabs
					stats(N r2 MEANs, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
					
			
		;
	# delimit cr 
 
 
// 2 - Export Individual Component Variables into Tables for each gender. 

	*FWB Component Results Export
	foreach SAMPLE in H S C {
	
			if "`SAMPLE'" == "C" {
				label var fin_ed "\textbf{Panel C: College+} \\ Fin Ed"
				local notes "nonotes"
				local mtitles ""
				local numbers "nonumbers"
			}
			else if "`SAMPLE'" == "S" {
				label var fin_ed "\textbf{Panel B: Some College} \\ Fin Ed"
				local notes "nonotes"
				local mtitles ""
				local numbers "nonumbers"
			}
			else if "`SAMPLE'" == "H" {
				label var fin_ed "\textbf{Panel A: High School Only} \\ Fin Ed"
				local notes "nonotes"
				local mtitles ""
				local numbers ""
			}
			

	# delimit ;
		esttab 
		        fwb1_exp_overall_noT_`SAMPLE'
				fwb2_getby_overall_noT_`SAMPLE'
				fwb3_secure_overall_noT_`SAMPLE'
				fwb4_concern_overall_noT_`SAMPLE'
				fwb5_never_overall_noT_`SAMPLE'
				fwb6_enjoy_overall_noT_`SAMPLE'
				fwb7_behind_overall_noT_`SAMPLE'
				fwb8_control_overall_noT_`SAMPLE'
				fwb9_strain_overall_noT_`SAMPLE'
				fwb10_left_overall_noT_`SAMPLE'
			using "out/appendix_tableB5_`SAMPLE'.tex",
					replace
					label
					keep(fin_ed)
					se
					b(3)
					se(3)
					`notes'
					`mtitles'
					`numbers'
					stats(N r2 MEANs, label("N" "\$R^2$" "DV Mean") fmt(%6.0fc %5.3f))
					booktabs
				
					
			
		;
	# delimit cr 
	
	}

	
	label var fin_ed "Fin Ed"
*/	


